Processor.App.Downloader.downloader.Downloader.\_\_init\_\_
===========================================================

.. currentmodule:: Processor.App.Downloader.downloader

.. automethod:: Downloader.__init__